# botocraft

**Documentation**: https://botocraft.readthedocs.org

[boto3](https://github.com/boto/boto3) is a wonderful library for interacting
with AWS resources, but it can be hard to use because there is little
standardization across services.

`botocraft` aims to be an opinionated interface to selected AWS resources that
at least provides a CRUDL interface to the resources it supports.

## Installation

`botocraft` supports Python 3.7+.

To install from PyPI:

```shell
pip install botocraft
```

## Supported services
